@@ -579,12 +579,15 @@ class Install(MethodsInterface):
         """
         Обновить список локальных администраторов при установке
         """
+        aliases = {
+            'update': 'system_update',
+        }
         install_admin = Admins(self.clVars, chroot=True)
         install_admin.clear()
         for k,v in self.clVars.select('install.cl_migrate_user',
                                       'install.cl_migrate_admin',
                                       install_cl_migrate_admin__ne=""):
-            install_admin[k] = v
+            install_admin[k] = aliases.get(v,v)
             install_admin.save()
         return True
 
