@@ -200,8 +200,8 @@ class VariableClGrubPasswdSet(GrubHelper, Variable):
     opt = ["--grub-passwd"]
 
     def init(self):
-        self.help = _("use root password for editing grub menu")
-        self.label = _("Use root password for editing grub menu")
+        self.help = _("use root password for editing boot menu")
+        self.label = _("Use root password for editing boot menu")
 
     def get(self):
         if (self.read_hash_from_passwd() or
@@ -314,6 +314,11 @@ class VariableClMigrateData(UserHelper, TableVariable):
         self.label = _("Migrating users")
 
     def set(self, value):
+        value = [
+            [x[0], {'none':''}.get(x[1],x[1]),
+            x[2],x[3]]
+            for x in value
+        ]
         if len(value) == 1:
             if len(value[0]) > 1 and value[0][0] == 'none':
                 return [[]]
@@ -359,6 +364,7 @@ class VariableClMigrateAdmin(UserHelper, Variable):
     """
     type = 'choice-list'
     default_value = ""
+    aliases = {'system_update': 'update'}
 
     def init(self):
         self.label = _("Administrator")
@@ -370,17 +376,18 @@ class VariableClMigrateAdmin(UserHelper, Variable):
             ("update", _("System update")),
         ]
 
+    def get_alias(self, value):
+        return self.aliases.get(value, value)
+
     def get(self):
         """
         Migrating users (users above 1000 uid)
         """
         admins = Admins(self.parent)
-        return [admins[x] or self.default_value
+        return [self.get_alias(admins[x]) or self.default_value
                 for x in self.Get('cl_migrate_user')]
 
     def set(self, value):
-        name_map = {'update':'system_update', 'none':''}
-        value = map(lambda x:name_map.get(x,x), value)
         return map(lambda x: x if x else self.default_value, value)
 
 
@@ -389,9 +396,9 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
     Migrate users groups
     """
     type = 'choice-list-list'
-    defaultGroupList = ["users", "wheel", "audio", "cdrom", "video",
+    defaultGroupList = sorted(["users", "wheel", "audio", "cdrom", "video",
                         "cdrw", "usb", "plugdev", "games", "lp", "scanner",
-                        "uucp"]
+                        "uucp"])
 
     def getDefaultGroups(self):
         return list(set(self.defaultGroupList) & set(getGroups()))
@@ -416,7 +423,7 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
         User groups
         """
         passwdList = getPasswdUsers()
-        return map(lambda x: (self.getPrimaryGroup(x) +
+        return map(lambda x: sorted(self.getPrimaryGroup(x) +
                               (getUserGroups(x)
                                if x in passwdList else
                                self.getDefaultGroups())),
@@ -426,7 +433,7 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
         """
         Available groups
         """
-        return [("", _("Default"))] + [(x, x) for x in getGroups()]
+        return [("", _("Default"))] + sorted([(x, x) for x in getGroups()])
 
 
 class VariableClMigrateUserPwd(UserHelper, Variable):
